@@ -7,76 +7,64 @@ use Carp;
 use IO::File;
 use File::Spec;
 use Log::Log4perl qw(get_logger);
-use Object::KVC;
 use Farly::Director;
-use Farly::IPv4::Address;
-use Farly::IPv4::Network;
-use Farly::IPv4::Range;
-use Farly::IPv4::ICMPType;
-use Farly::Transport::Port;
-use Farly::Transport::PortGT;
-use Farly::Transport::PortLT;
-use Farly::Transport::PortRange;
-use Farly::Transport::Protocol;
+use Farly::Object;
 
-our $VERSION = '0.12';
+our $VERSION = '0.20';
 
-our ($volume,$dir,$file) = File::Spec->splitpath( $INC{'Farly.pm'} );
-Log::Log4perl::init( $volume.$dir.'Farly/Log/Farly.conf');
+Log::Log4perl::init( '/etc/farly/logging.conf' );
 
 sub new {
-	my ( $class, $container ) = @_;
+    my ( $class, $container ) = @_;
 
-	my $self = { DIRECTOR => Farly::Director->new(), };
-	bless $self, $class;
+    my $self = { DIRECTOR => Farly::Director->new(), };
+    bless $self, $class;
 
-	my $logger = get_logger(__PACKAGE__);
-	$logger->info("$self NEW");
+    my $logger = get_logger(__PACKAGE__);
+    $logger->info("$self NEW");
 
-	return $self;
+    return $self;
 }
 
 sub director {
-	return $_[0]->{DIRECTOR};
+    return $_[0]->{DIRECTOR};
 }
 
 sub process {
-	my ( $self, $type, $file_name ) = @_;
+    my ( $self, $type, $file_name ) = @_;
 
-	croak "$file_name is not a file" unless ( -f $file_name );
+    croak "$file_name is not a file" unless ( -f $file_name );
 
-	my $logger = get_logger(__PACKAGE__);
+    my $logger = get_logger(__PACKAGE__);
 
-	my $location     = "Farly/$type/Builder.pm";
-	my $builder_class = "Farly::".$type."::Builder";
+    my $location      = "Farly/$type/Builder.pm";
+    my $builder_class = 'Farly::'.$type.'::Builder';
 
-	require $location;
-	
-	my $builder = $builder_class->new();
+    require $location;
 
-	my $file = IO::File->new($file_name);
+    my $builder = $builder_class->new();
 
-	$self->director()->set_file($file);
-	$self->director()->set_builder($builder);
+    my $file = IO::File->new($file_name);
 
-	my $start = [ Time::HiRes::gettimeofday() ];
+    $self->director()->set_file($file);
+    $self->director()->set_builder($builder);
 
-	my $container;
-	
-	eval {
-		$container = $self->director()->run();
-	};
-	if ($@) {
-		die "Import of $file_name failed\n",$@,"\n";
-	}
-	
-	my $elapsed = Time::HiRes::tv_interval($start);
+    my $start = [ Time::HiRes::gettimeofday() ];
 
-	$logger->info("parse time: $elapsed seconds");
+    my $container;
 
-	$logger->info("imported ",$container->size()," objects");
+    eval { $container = $self->director()->run(); };
+    if ($@) {
+        die "Import of $file_name failed\n", $@, "\n";
+    }
 
-	return $container;
+    my $elapsed = Time::HiRes::tv_interval($start);
+
+    $logger->info("parse time: $elapsed seconds");
+
+    $logger->info( "imported ", $container->size(), " objects" );
+
+    return $container;
 }
 
 1;
@@ -97,7 +85,7 @@ group or rule optimizations or large scale firewall
 configuration changes.
 
 This module is a factory class which abstracts the 
-construction of an Object::KVC::List<Object::KVC::Hash> based
+construction of an Farly::Object::List<Farly::Object> based
 firewall device model.
 
 Farly dies on error.
@@ -125,7 +113,7 @@ The constructor. No arguments required.
 
  my $container = $importer->process("ASA", "firewall-config.txt");
 
-Returns Object::KVC::List<Object::KVC::Hash> firewall device model.
+Returns Farly::Object::List<Farly::Object> firewall device model.
  
 Valid firewall types:
  ASA  - Cisco ASA firewall
